@@ -11,7 +11,7 @@
 #' @seealso Use \code{\link{is_beast2_input_file}} to check a file
 #' @examples
 #' if (is_beast2_installed() && is_on_ci()) {
-#'   get_beastier_path("anthus_2_4.xml")
+#'   are_beast2_input_lines(get_beastier_path("anthus_2_4.xml"))
 #' }
 #' @export
 are_beast2_input_lines <- function(
@@ -24,19 +24,20 @@ are_beast2_input_lines <- function(
     stop("'method' must be \"deep\" or \"fast\", value was '", method, "'")
   }
   if (method == "deep") {
-    filename <- tempfile()
+    filename <- beastier::get_beastier_tempfilename()
+    dir.create(dirname(filename), showWarnings = FALSE, recursive = TRUE)
     beastier::save_lines(filename = filename, lines = lines)
-    return(
-      are_beast2_input_lines_deep(
-        lines = lines,
-        verbose = verbose,
-        beast2_path = beast2_path
-      )
+    is_valid <- beastier::are_beast2_input_lines_deep(
+      lines = lines,
+      verbose = verbose,
+      beast2_path = beast2_path
     )
+    file.remove(filename)
+    return(is_valid)
   } else {
     testit::assert(method == "fast")
     return(
-      are_beast2_input_lines_fast(lines) # nolint internal function
+      beastier::are_beast2_input_lines_fast(lines) # nolint internal function
     )
   }
 }
@@ -54,7 +55,7 @@ are_beast2_input_lines <- function(
 #' if (is_beast2_installed() && is_on_ci()) {
 #'   beast2_filename <- get_beastier_path("anthus_2_4.xml")
 #'   text <- readLines(beast2_filename)
-#'   testit::assert(are_beast2_input_lines_deep(text))
+#'   are_beast2_input_lines_deep(text)
 #' }
 #' @export
 are_beast2_input_lines_deep <- function(
@@ -62,19 +63,16 @@ are_beast2_input_lines_deep <- function(
   verbose = FALSE,
   beast2_path = get_default_beast2_path()
 ) {
-  filename <- file.path(
-    rappdirs::user_cache_dir(),
-    basename(
-      tempfile(pattern = "beast2_", fileext = ".xml")
-    )
-  )
+  filename <- beastier::create_temp_input_filename()
   dir.create(dirname(filename), recursive = TRUE, showWarnings = FALSE)
   beastier::save_lines(filename = filename, lines = lines)
-  beastier::is_beast2_input_file(
+  is_valid <- beastier::is_beast2_input_file(
     filename = filename,
     verbose = verbose,
     beast2_path = beast2_path
   )
+  file.remove(filename)
+  is_valid
 }
 
 #' Would these lines of text, when written to a file,
