@@ -12,22 +12,13 @@ check_can_create_treelog_file <- function(
 ) {
   # Extract the treelog file
   testthat::expect_true(file.exists(beast2_options$input_filename))
-  text <- readr::read_lines(beast2_options$input_filename)
-  treelog_line <- stringr::str_subset(
-    string = text,
-    pattern = "<logger id=\"treelog.t:"
+  treelog_filename <- beastier::extract_treelog_filename_from_beast2_input_file(
+    input_filename = beast2_options$input_filename
   )
-  testthat::expect_equal(length(treelog_line), 1)
-  matches <- stringr::str_match(
-    string = treelog_line,
-    pattern = "fileName=\\\"([:graph:]+)\\\" "
-  )
-  testthat::expect_equal(ncol(matches), 2)
-  treelog_filename <- matches[1, 2]
 
   if (file.exists(treelog_filename)) {
      file.remove(treelog_filename)
-     return()
+     return(invisible(beast2_options))
   }
 
   tryCatch(
@@ -38,4 +29,5 @@ check_can_create_treelog_file <- function(
       stop("Cannot create treelog file '", treelog_filename, "'")
     }
   )
+  invisible(beast2_options)
 }
